Word Highlighter
================

Word highlighter supporting Named Entity Recognition and Part of Speech tagging for Dutch and English documents.

**Inputs**

- Corpus: A dataset of one or more textual documents in Dutch or English.

**Outputs**

- Table: A data table providing all identified entities in each sentence of the input text documents.

**Word Highlighter** widget applies NER and POS-tagging to sentences. It highlights the identified entities inline in the input text documents.

![](images/dsgtagger-example2.png)

Example
-------

This simple example shows how **Word Highlighter** can enrich the workflow. We have used a dataset of Dutch narrative stories about the corona pandemic.